import "WalmPlugins.WarbandsSlayer.src.StringLib";
import "WalmPlugins.WarbandsSlayer.src.WarbandsNode";
import "WalmPlugins.WarbandsSlayer.src.AreaNode";
import "WalmPlugins.WarbandsSlayer.src.ToggleButton";
import "WalmPlugins.WarbandsSlayer.src.Rewards";
import "WalmPlugins.WarbandsSlayer.src.WarbandsData";
import "WalmPlugins.WarbandsSlayer.src.WarbandPane";
import "WalmPlugins.WarbandsSlayer.src.ConfigurationDialog";
import "WalmPlugins.WarbandsSlayer.src.DateTimeUtils";
import "WalmPlugins.WarbandsSlayer.src.Tooltip";
import "WalmPlugins.WarbandsSlayer.src.TabButton";

WarbandsDialog = class( Turbine.UI.Lotro.Window );
warbandsCooldowns = nil;
Filters = {
	show1 = false,
	show3 = false,
	show6 = false,
	show12 = false,
	todo = true,
	done = true,
	search = "",
	unrepeat = true,
	-- targetEriadorTgBtn = true,
	-- targetRhovanionTgBtn = true,
	-- targetGondorTgBtn = true;
	-- targetMordorBtn = true;
};

function WarbandsDialog:Constructor()
	Turbine.UI.Lotro.Window.Constructor( self );
	
	self:SetSize( 765, 574 );
	self:SetVisible(false);
	
	self:LoadFilters();		
	LoadPOI();		
	
	self:SetText( "Mort aux Troupes de Guerre !" );	
	
	self.Closed = function(sender, args)
		self:Stop();
	end
	self.PositionChanged = function(sender, args)
		Preferences.main_x, Preferences.main_y = self:GetPosition();
		SavePreferences();
	end
	-- Hide UI when F12 is pressed, code copied from Chiran sources
	local hideUI = false;
	local wasVisible;
	self:SetWantsKeyEvents(true);
	self.KeyDown = function(sender, args)
		if (args.Action == 268435635) then
			if not hideUI then
				hideUI = true;
				if self:IsVisible() then
					wasVisible = true;
					self:SetVisible(false);					
				else
					wasVisible = false;
				end
			else
				hideUI = false;
				if wasVisible then
					self:SetVisible(true);				
				end
			end
		end
	end	
	
	self:CreateParametersButton();
	self:ConstructTreeNode();
	self:ConstructHeader();
	self:ConstructSearchComponents();
	self.warbandPane = WarbandPane(380, 433);
	self.warbandPane:SetParent( self );	
	self.warbandPane:SetPosition( 380, 105 );
	self:ShowAllWarbands();	
	self:InitChatLogger();
	self:LoadCooldowns();	
	
	self:ApplyPreferences();
	self:ApplyFilters();
	self:ShowEnemyTab(Filters.tab);
end	

function WarbandsDialog:ApplyPreferences()
	self:SetPosition(Preferences.main_x, Preferences.main_y);
	
	if(self.lastCdPref ~= Preferences.utcResetHour) then
		self:LoadCooldowns(); -- recalcul les cds avec la nouvelle heure de reset
	end
	self.lastCdPref = Preferences.utcResetHour;
	
	self:SetWantsUpdates(Preferences.autoUpdate);
end

function WarbandsDialog:Update( args )
	--PrintDate(self.nextcd, "nextcd");
	--Turbine.Shell.WriteLine("<rgb=#FF5CCD>UPDATE WarbandsDialog</rgb>");
	if(Preferences.autoUpdate and CompareDate(self.nextcd)) then
		Turbine.Shell.WriteLine("<rgb=#FF5CCD>"..ToUTF8("Rinitialisation des cooldowns de qutes de Troupes de Guerre").." !</rgb>");
		self:LoadCooldowns(); -- recalcul les cds		
		--Turbine.Shell.WriteLine("<rgb=#FF5CCD>Init DONE !!!!</rgb>");
	end
end

function WarbandsDialog:ConstructTreeNode()
	self.treeView = Turbine.UI.TreeView();
    self.treeView:SetParent( self );
    self.treeView:SetPosition( 10, 105 );
    self.treeView:SetSize( 350, 433 );
    self.treeView:SetIndentationWidth( 15 );
	local treeViewScrollBar = Turbine.UI.Lotro.ScrollBar();
    treeViewScrollBar:SetOrientation( Turbine.UI.Orientation.Vertical );
    treeViewScrollBar:SetParent( self );
    treeViewScrollBar:SetPosition( 360, 105 );
    treeViewScrollBar:SetSize( 10, 433 );
	self.treeView:SetVerticalScrollBar( treeViewScrollBar );
	self.treeView.SelectedNodeChanged = function(sender, args)
		local node = self.treeView:GetSelectedNode();		
		if(node~=nil and node.warband~=nil) then
			self.warbandPane:SetWarband(node.warband, self:GetWarbandCooldown(node.warband.id), node:GetParentNode():GetValue());
		end		
	end
	
	self:PopupateTreeView();
end

function WarbandsDialog:CreateParametersButton()
	local lowerSep = Turbine.UI.Control();
	lowerSep:SetParent( self );
	lowerSep:SetSize( self:GetWidth()-8 , 2 );
	lowerSep:SetPosition( 4, self:GetHeight()-34 );	
	lowerSep:SetBackColor( Turbine.UI.Color(0.5, 0.5, 0.5) );
	lowerSep:SetZOrder(99);

	local optionbtn = Turbine.UI.Lotro.Button();
    optionbtn:SetParent( self );
    optionbtn:SetPosition( 640, 545 );
    optionbtn:SetSize( 90, 18 );
    optionbtn:SetText(ToUTF8("Paramtres"));
	optionbtn.Click = function( sender, args )
		local configDialog = GetConfigurationDialogInstance();
		configDialog:SetVisible(true);
	end
end

function WarbandsDialog:ConstructHeader()
	local headerIco = Turbine.UI.Control();
	headerIco:SetParent( self );
	headerIco:SetSize( 756, 48 );
	headerIco:SetPosition( 5, 58 );
	headerIco:SetZOrder( -99);
	headerIco:SetBackground("WalmPlugins/WarbandsSlayer/resources/header2.tga");
	headerIco:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );
	
	local iconExpandAll = Turbine.UI.Control();
	iconExpandAll:SetParent( self );
	iconExpandAll:SetSize( 16, 16 );
	iconExpandAll:SetPosition( 16, 76 );
	iconExpandAll:SetBackground( 0x41007E27 );
	iconExpandAll:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );	
	iconExpandAll.MouseClick = function( sender, args )
		self:ShowAllWarbands();
	end

	local iconCollapseAll = Turbine.UI.Control();
	iconCollapseAll:SetParent( self );
	iconCollapseAll:SetSize( 16, 16 );
	iconCollapseAll:SetPosition( 38, 76 );
	iconCollapseAll:SetBackground( 0x41007E26 );
	iconCollapseAll:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );
	iconCollapseAll.MouseClick = function( sender, args )
		self:CollapseAllWarbands();
	end	
	
	local upperSep = Turbine.UI.Control();
	upperSep:SetParent( self );
	upperSep:SetSize( self:GetWidth()-8 , 2 );
	upperSep:SetPosition( 4, 102 );	
	upperSep:SetBackColor( Turbine.UI.Color(0.5, 0.5, 0.5) );
	upperSep:SetZOrder(99);
	
	local warbandTab = TabButton("Troupes de Guerre", true);
	warbandTab:SetParent(self);
	warbandTab:SetPosition( 25, 38 );
	local rovingThreatTab = TabButton(ToUTF8("Menaces itinrantes"), false);
	rovingThreatTab:SetParent(self);
	rovingThreatTab:SetPosition( 180, 38 );
	local poitTab = TabButton(ToUTF8("Points d'intert"), false);
	poitTab:SetParent(self);
	poitTab:SetPosition( 335, 38 );		
	warbandTab.MouseClick = function()
		warbandTab:SetSelected(true);
		rovingThreatTab:SetSelected(false);
		poitTab:SetSelected(false);		
		self.warbandPane:SetWarband(nil);
		self:ShowEnemyTab(1);
	end
	rovingThreatTab.MouseClick = function()
		warbandTab:SetSelected(false);
		rovingThreatTab:SetSelected(true);
		poitTab:SetSelected(false);			
		self.warbandPane:SetWarband(nil);
		self:ShowEnemyTab(2);
	end
	poitTab.MouseClick = function()
		warbandTab:SetSelected(false);
		rovingThreatTab:SetSelected(false);
		poitTab:SetSelected(true);			
		self.warbandPane:SetWarband(nil);
		self:ShowEnemyTab(3);
	end	
	warbandTab:SetSelected(Filters.tab==nil or Filters.tab==1);
	rovingThreatTab:SetSelected(Filters.tab==2);
	poitTab:SetSelected(Filters.tab==3);
	--self:ShowEnemyTab(1);
	self:ConstructFilters();
end

function WarbandsDialog:ShowEnemyTab(enemyTab)
	if(enemyTab==nil) then
		enemyTab = 1;
	end
	if(enemyTab==1) then
		self:SetText("Mort aux Troupes de Guerre");
	elseif(enemyTab==2) then
		self:SetText(ToUTF8("Mort aux Menaces Itinrantes"));
	elseif(enemyTab==3) then
		self:SetText(ToUTF8("Points d'intert"));		
	end
	
	self.targetEriadorTgBtn:TabVisibility(enemyTab);
	self.targetRhovanionTgBtn:TabVisibility(enemyTab);
	self.targetGondorTgBtn:TabVisibility(enemyTab);
	self.targetMordorBtn:TabVisibility(enemyTab);
	
	Filters.tab = enemyTab;
	self:ApplyFilters();
	self:SaveFilters(false);
	self:ReloadCdCounters();
end

function WarbandsDialog:ConstructFilters()

	self.size1TgBtn = ToggleButton	(32, 29, "WalmPlugins/WarbandsSlayer/resources/btn/btn_size_1_off.jpg");
	self.size1TgBtn:SetParent( self );	
	self.size1TgBtn:SetPosition( 94, 68 );
	self.size1TgBtn:SetChecked(not Filters.show1 );
	ToolTip(self.size1TgBtn, "Solo", ToUTF8("Permet d'afficher ou masquer les qutes solotables."));
	self.size1TgBtn.Toggled = function(sender, selected)
		Filters.show1 = not selected;
		self:ApplyFilters();
		self:SaveFilters();
	end
	self.size3TgBtn = ToggleButton	(32, 29, "WalmPlugins/WarbandsSlayer/resources/btn/btn_size_3_off.jpg", Filters.show3);
	self.size3TgBtn:SetParent( self );	
	self.size3TgBtn:SetPosition( 128, 68 );
	self.size3TgBtn:SetChecked(not Filters.show3 );
	ToolTip(self.size3TgBtn, ToUTF8("Petite communaut"), ToUTF8("Permet d'afficher ou masquer les qutes pour 3 hros."));
	self.size3TgBtn.Toggled = function(sender, selected)
		Filters.show3 = not selected;
		self:ApplyFilters();
		self:SaveFilters();		
	end	
	self.size6TgBtn = ToggleButton	(32, 29, "WalmPlugins/WarbandsSlayer/resources/btn/btn_size_6_off.jpg", Filters.show6);
	self.size6TgBtn:SetParent( self );	
	self.size6TgBtn:SetPosition( 162, 68 );
	self.size6TgBtn:SetChecked(not Filters.show6 );
	ToolTip(self.size6TgBtn, ToUTF8("Communaut"), ToUTF8("Permet d'afficher ou masquer les qutes de communaut."));
	self.size6TgBtn.Toggled = function(sender, selected)
		Filters.show6 = not selected;
		self:ApplyFilters();
		self:SaveFilters();		
	end	
	self.size12TgBtn = ToggleButton (32, 29, "WalmPlugins/WarbandsSlayer/resources/btn/btn_size_12_off.jpg", Filters.show12);
	self.size12TgBtn:SetParent( self );	
	self.size12TgBtn:SetPosition( 196, 68 );
	self.size12TgBtn:SetChecked(not Filters.show12 );
	ToolTip(self.size12TgBtn, "Raid", ToUTF8("Permet d'afficher ou masquer les qutes pour 12 hros."));
	self.size12TgBtn.Toggled = function(sender, selected)
		Filters.show12 = not selected;
		self:ApplyFilters();
		self:SaveFilters();		
	end
	self.doneTgBtn = ToggleButton (32, 29, "WalmPlugins/WarbandsSlayer/resources/btn/btn_done2.jpg");
	self.doneTgBtn:SetParent( self );	
	self.doneTgBtn:SetPosition( 274, 68 );
	self.doneTgBtn:SetVisible(not Preferences.win31Style);
	ToolTip(self.doneTgBtn, ToUTF8("Qutes faites"), ToUTF8("Permet d'afficher ou masquer les qutes dj faites."));
	self.doneTgBtn:SetChecked(Filters.done);
	self.doneTgBtn.Toggled = function(sender, selected)
		Filters.done = selected;
		self:ApplyFilters();
		self:SaveFilters();		
	end
	self.todoTgBtn = ToggleButton (32, 29, "WalmPlugins/WarbandsSlayer/resources/btn/btn_todo.jpg");
	self.todoTgBtn:SetParent( self );	
	self.todoTgBtn:SetPosition( 240, 68 );
	self.todoTgBtn:SetVisible(not Preferences.win31Style);
	ToolTip(self.todoTgBtn, ToUTF8("Qutes  faire"), ToUTF8("Permet d'afficher ou masquer les qutes restant  faire."));
	self.todoTgBtn:SetChecked(Filters.todo);
	self.todoTgBtn.Toggled = function(sender, selected)
		Filters.todo = selected;
		self:ApplyFilters();
		self:SaveFilters();		
	end

	local leftbuttonpos = 320;
	local buttonspace = 35;


	self.targetEriadorTgBtn = self:CreateRTButton("Eriador", "de l'Eriador", "filtre_northdowns.tga", "targetEriador", -1, 0, 0);
	self.targetRhovanionTgBtn = self:CreateRTButton("Rhovanion", "du Rhovanion", "filtre_erohan.tga", "targetRhovanion", 0, 1, 1);
	self.targetGondorTgBtn = self:CreateRTButton("Gondor", "du Gondor", "filtre_wgondor.tga", "targetGondor", 1, 2, 2);
	self.targetMordorBtn = self:CreateRTButton("Mordor", "du Mordor", "filtre_mordor.tga", "filtre_fanorien", 2, 3, 3);
end

function WarbandsDialog:CreateRTButton(regionName, regionLName, btnpictName, filter, wbPos, rtPos, poiPos)
	local toggleButton = ToggleButton (32, 29, "WalmPlugins/WarbandsSlayer/resources/btn/"..btnpictName);

	toggleButton:SetParent( self );
	toggleButton.wbPos = wbPos;
	toggleButton.rtPos = rtPos;
	toggleButton.poiPos = poiPos;
	toggleButton:SetPosition( 325 + 35*wbPos, 68 );
	toggleButton:SetVisible(not Preferences.win31Style);
	ToolTip(toggleButton, regionName, ToUTF8("Permet de se focaliser sur les ennemis "..regionLName));
	toggleButton:SetChecked(Filters[filter]==nil or Filters[filter]==true);
	
	toggleButton.Toggled = function(sender, selected)
		--Turbine.Shell.WriteLine("Filters : "..filter.." = "..Filters[filter]);
		Filters[filter] = selected;
		self:ApplyFilters();
		self:SaveFilters();		
	end	
	toggleButton.TabVisibility = function(params, tab)
		if(tab==1) then
			toggleButton:SetVisible(wbPos~=-1);
			toggleButton:SetPosition( 325 + 35*wbPos, 68 );
		elseif (tab==2) then
			toggleButton:SetVisible(rtPos~=-1);
			toggleButton:SetPosition( 325 + 35*rtPos, 68 );
		elseif (tab==3) then
			toggleButton:SetVisible(poiPos~=-1);
			toggleButton:SetPosition( 325 + 35*poiPos, 68 );
		end
	end
	return toggleButton;
end

function WarbandsDialog:InitChatLogger()	
	if(Turbine.Chat.receivedListerners == nil) then
		Turbine.Chat.receivedListerners = {};
		Turbine.Chat.Received = function (sender, args)
			for i, j in pairs(Turbine.Chat.receivedListerners) do
				j:OnReceived(sender, args);
			end
		end
		-- local tempMessage = tostring(args.Message);
	end
	if (Turbine.Chat.receivedListerners ~= nil) then
		for i, j in pairs(Turbine.Chat.receivedListerners) do
			if(j==self) then return; end
		end
		table.insert(Turbine.Chat.receivedListerners, self);
		--Turbine.Shell.WriteLine( "WarbandsDialog ECHO: "..table.getn(Turbine.Chat.receivedListerners));
	end	
end

function WarbandsDialog:OnReceived(sender, args)
	if args.ChatType == Turbine.ChatType.Quest then
		local tempMessage = tostring(args.Message);
		--Turbine.Shell.WriteLine("<rgb=#FF5CCD>WarbandsDialog ECHO : ".. tempMessage .."</rgb>");
		local x, y, wbName = string.find(tempMessage, "^Termin\195\169[\194\160%s]*:[\194\160%s]*Troupe de guerre[\194\160%s]*:(.*)$");			
		if(wbName ~= nil) then
			Turbine.Shell.WriteLine("<rgb=#FF5CCD>wbName : "..wbName.."</rgb>");
			self:AddCooldown(nil, wbName);
		else
			x, y, wbName = string.find(tempMessage, "^Termin\195\169.*:\n(.*)$"); -- Termin:Mordechair, Flau de Lhingris
			if(wbName ~= nil) then
				self:AddCooldown(nil, wbName);
			else
			-- Putain de fix pour les bugs de Turbine de traductions !!!!
				x, y, wbName = string.find(tempMessage, "^Termin\195\169.*:.*Warband.*:(.*)$"); -- Termin:Warband: Adrjan the Brute	
				if(wbName ~= nil) then
					self:AddCooldown(nil, wbName);
				end
			end
		end
		local x2, y2, rtName = string.find(tempMessage, "^Termin\195\169[\194\160%s]*:[\194\160%s]*Menace itin\195\169rante[\194\160%s]*:(.*)$");
		if(rtName ~= nil) then
			Turbine.Shell.WriteLine("<rgb=#FF5CCD>rtName : "..rtName.."</rgb>");
			self:AddCooldown(nil, rtName);
		end
	end
end

function WarbandsDialog:AddCooldown(wb, wbName, alwaysOn, verbose)
	if(wb == nil) then
		wb = GetWarbandByQuestName(wbName);
		if(wb == nil) then
			local wbName2 = StringCleaner(wbName);
			wb = GetWarbandByQuestName(wbName2);
		end
		if(wb == nil) then
			--Turbine.Shell.WriteLine("<rgb=#FF5CCD>Erreur, aucune troupe de guerre ou Menace itin\195\169rante du nom de "..wbName.." trouv\195\169e. Cette Troupe est donc ignor\195\169e!</rgb>");
			return;
		end
		--Turbine.Shell.WriteLine(ToUTF8("<rgb=#FF5CCD>".. wb.name .." FOUND</rgb>"));
	end
	local notified = (verbose==nil or verbose==true);
	if(warbandsCooldowns == nil) then
		self:LoadCooldowns();
		notified = false;
	
	end
	--Turbine.Shell.WriteLine("<rgb=#FF5CCD>DEMANDE DE COOLDOWN: "..wbName);
	for i=1, table.getn(warbandsCooldowns), 1 do
		if(warbandsCooldowns[i][1]==wb.id) then			
			warbandsCooldowns[i][2] = Turbine.Engine.GetDate();
			if(warbandsCooldowns[i][3]==nil) then warbandsCooldowns[i][3]=0; end -- fix update issue
			warbandsCooldowns[i][3] = warbandsCooldowns[i][3] + 1;
			warbandsCooldowns[i][4] = alwaysOn;			
			self:UpdateNodeStatus(wb.id, warbandsCooldowns[i][2], false, alwaysOn);
			self:SaveCooldowns( notified);
			if(self.warbandPane~=nil and self.warbandPane.wb~=nil and self.warbandPane.wb.id==wb.id) then
				self.warbandPane:SetWarband(wb, warbandsCooldowns[i]);
			end
			return;
		end
	end
	local cd = {wb.id, Turbine.Engine.GetDate(), 1};
	table.insert(warbandsCooldowns, cd);
	self:UpdateNodeStatus(wb.id, cd[2], false, alwaysOn);
	self:SaveCooldowns( notified);
	self:ApplyFilters();
	if(self.warbandPane~=nil and self.warbandPane.wb~=nil and self.warbandPane.wb.id==wb.id) then
		self.warbandPane:SetWarband(wb, cd);
	end
end

function WarbandsDialog:GetWarbandCooldown(wbId)
	for i=1, table.getn(warbandsCooldowns), 1 do
		if(warbandsCooldowns[i][1]==wbId) then
			return warbandsCooldowns[i];
		end
	end
	return nil;
end

function WarbandsDialog:FocusOnWarband(wb)
	
	if(wb==nil) then
		
		return;
	end
	for i=1, self.treeView:GetNodes():GetCount(), 1 do
		local node = self.treeView:GetNodes():Get(i):GetWarbandNode(wb);
		if(node~=nil) then
			self.treeView:SetSelectedNode(node);
			
			return true;
		end
	end	
	
	return false;
end

function WarbandsDialog:UpdateNodeStatus(wbId, wbLastKill, cdUp, alwaysOn)
	--Turbine.Shell.WriteLine("<rgb=#FF5CCD>Node to update: "..wbId.."</rgb>");
	for i=1, self.treeView:GetNodes():GetCount(), 1 do
		self.treeView:GetNodes():Get(i):UpdateWBNodeStatus(wbId, wbLastKill, cdUp, alwaysOn);
	end	
end

function WarbandsDialog:SaveFilters(verbose)
	DataSave(Turbine.DataScope.Character, "MortAuxTroupesDeGuerre_filters", Filters);
	if(verbose==nil or verbose==true) then
		Turbine.Shell.WriteLine(ToUTF8("<rgb=#FF5CCD>Mort aux Troupes de Guerre: Filtres sauvegards</rgb>"));
	end
end

function WarbandsDialog:LoadFilters()
	local tmpFilters = DataLoad(Turbine.DataScope.Character, "MortAuxTroupesDeGuerre_filters");
	if(tmpFilters ~= nil) then
		Filters = tmpFilters;		
		Filters.search = "";
	end
end

function SavePOI(verbose)
	DataSave(Turbine.DataScope.Character, "MortAuxTroupesDeGuerre_poi", PoiProgress);
	if(verbose==nil or verbose==true) then
		Turbine.Shell.WriteLine(ToUTF8("<rgb=#FF5CCD>Mort aux Troupes de Guerre: Progression sauvegards</rgb>"));
	end
end

function LoadPOI()
	local tmpPOIProgress = DataLoad(Turbine.DataScope.Character, "MortAuxTroupesDeGuerre_poi");
	if(tmpPOIProgress ~= nil) then
		PoiProgress = tmpPOIProgress;				
	end
end

function WarbandsDialog:SaveCooldowns(notify)
	-- Format {{wb_id, lastkill_date
	DataSave(Turbine.DataScope.Character, "MortAuxTroupesDeGuerre_progress", warbandsCooldowns);
	--Turbine.Shell.WriteLine(ToUTF8("<rgb=#FF5CCD>Mort aux Troupes de Guerre: Progression sauvegarde</rgb>"));
	
	if(notify~=nil and notify==true) then
		self:ReloadCdCounters();
	end
end

function WarbandsDialog:ReloadCdCounters(doneCount, total)
	if(total == nil) then
		total = GetWarbandsCount(Filters.tab);
	end
	if(doneCount==nil) then
		local cd_count = 0;
		local lastcd = GetLastCdTime();		
		for i=1, table.getn(warbandsCooldowns), 1 do
			local cd = CompareDate(lastcd, warbandsCooldowns[i][2]);
			local wb = GetWarbandById(warbandsCooldowns[i][1]);
			--local alwaysOn = (warbandsCooldowns[i][4]==true);
			if(wb~=nil) then
				local wbType = wb.enemyType or 1;
				if(wbType == Filters.tab) then
					if(cd and warbandsCooldowns[i][4]~=false) then 
						cd_count=cd_count+1;
					elseif(wb~=nil and (wb.repeatable==false or wb.enemyType==3)) then
						cd_count=cd_count+1;
					end
				end
			end
		end		
		self:NotifyUpdate(cd_count, total, false, Filters.tab); -- FIXME 0 en attendant le formatage des donnes 
	else
		self:NotifyUpdate(doneCount, total, true, Filters.tab);
	end
end

function WarbandsDialog:NotifyUpdate(doneCount, total)
	--Turbine.Shell.WriteLine("<rgb=#FF5CCD>Vous avez aujourd\'hui trucid\195\169 "..doneCount.." troupes de guerre sur "..total..".</rgb>");
end

function WarbandsDialog:LoadCooldowns()
	-- Format {{wb_id, lastkill_Date, killcount},...}
	if(warbandsCooldowns == nil) then
		warbandsCooldowns = DataLoad(Turbine.DataScope.Character, "MortAuxTroupesDeGuerre_progress");
		if(warbandsCooldowns == nil) then
			warbandsCooldowns = {};
		end
	end
	self.lastcd = GetLastCdTime();
	self.nextcd = GetNextCdTime();
	local cd_count = 0;
	--PrintDate(self.lastcd, "<rgb=#FF5CCD>self.lastcd => </rgb>");	
	for i=1, table.getn(warbandsCooldowns), 1 do
		local cd = CompareDate(self.lastcd, warbandsCooldowns[i][2]);
		self:UpdateNodeStatus(warbandsCooldowns[i][1], warbandsCooldowns[i][2], not cd, warbandsCooldowns[i][4]);
		if(cd or (warbandsCooldowns[i][4]~=nil and warbandsCooldowns[i][4]==true)) then cd_count=cd_count+1; end
	end
	--self:ReloadCdCounters(cd_count, nil);
	self:ReloadCdCounters();
end

function WarbandsDialog:PopupateTreeView()
	rootNodes = self.treeView:GetNodes();	
	rootNodes:Clear();
	
	for i=1, table.getn(wadData), 1 do
		local mapNode = AreaNode(wadData[i].name);
		rootNodes:Add( mapNode );
		if(wadData[i].areas ~= nil) then
			for j=1, table.getn(wadData[i].areas), 1 do
				local area = wadData[i].areas[j];
				local subareaNode = AreaNode(area.name);
				if area.showme==false then subareaNode:AlwaysHideMe(); end
				mapNode:GetChildNodes():Add(subareaNode);
				--Turbine.Shell.WriteLine("<rgb=#FF5CCD>REGION : "..area.name.."</rgb>");
				if(area.wads ~= nil) then
					for k=1, table.getn(area.wads), 1 do
						local wad = area.wads[k];
						if(wad.map==nil) then
							if(area.map~=nil) then wad.map=area.map ;
							else wad.map=wadData[i].map; end
						end
						if(wad.rovingThreatData==nil) then
							if(area.rovingThreatData~=nil) then wad.rovingThreatData=area.rovingThreatData ;
							else wad.rovingThreatData=wadData[i].rovingThreatData; end
						end						
						local wadNode = WarbandsNode(wad, wadData[i].region);
						subareaNode:GetChildNodes():Add(wadNode);
						--Turbine.Shell.WriteLine("<rgb=#FF5CCD>	2326 : "..wad.name.."</rgb>");
					end
				end
			end
		end
	end
end

function WarbandsDialog:ConstructSearchComponents()
	searchLabel = Turbine.UI.Label();
	searchLabel:SetParent( self );
	searchLabel:SetFont(Turbine.UI.Lotro.Font.Verdana12);	
	searchLabel:SetText( "Recherche :");
	searchLabel:SetForeColor(Turbine.UI.Color( 1, 1, 0.5 ));
	searchLabel:SetPosition( 512, 77 );
	searchLabel:SetSize(100, 30);
	searchLabel:SetMouseVisible( false );	

	searchTextAreaBorder = Turbine.UI.Label();
	searchTextAreaBorder:SetParent( self );
	--searchTextAreaBorder:SetFont(Turbine.UI.Lotro.Font.Verdana12);	
	--searchTextAreaBorder:SetText( "Recherche :");
	searchTextAreaBorder:SetBackColor(Turbine.UI.Color( 1, 1, 0.5 ));
	searchTextAreaBorder:SetPosition( 580, 73 );
	searchTextAreaBorder:SetSize(152, 20);
	searchTextAreaBorder:SetMouseVisible( false );	
	searchTextArea = Turbine.UI.TextBox();
	searchTextArea:SetParent( searchTextAreaBorder );
	searchTextArea:SetText("");
	searchTextArea:SetTextAlignment( Turbine.UI.ContentAlignment.MiddleLeft );
	searchTextArea:SetPosition( 1, 1 );
	searchTextArea:SetBackColor(Turbine.UI.Color( 0, 0, 0 ));
	searchTextArea:SetSize(150, 18);
	searchTextArea:SetMultiline(false);
	searchTextArea.KeyDown = function(sender, args)		
		Filters.search = string.lower(searchTextArea:GetText());
		--Filters.search = UtfToRawLower(searchTextArea:GetText());
		self:ApplyFilters();
	end
	

	
	--self:SetBackColor(Turbine.UI.Color( 1, 0.4, 0.4, 1 ));
end

function WarbandsDialog:ApplyFilters()
	for i=1, self.treeView:GetNodes():GetCount(), 1 do
		self.treeView:GetNodes():Get(i):AppliFilters(Filters);
	end
	--self:ShowAllWarbands();
end

function WarbandsDialog:ShowAllWarbands()
	for i=1, self.treeView:GetNodes():GetCount(), 1 do
		self.treeView:GetNodes():Get(i):ExpandAll();
	end
end

function WarbandsDialog:CollapseAllWarbands()
	for i=1, self.treeView:GetNodes():GetCount(), 1 do
		self.treeView:GetNodes():Get(i):CollapseAll();
	end
end

function WarbandsDialog:GetName()
	return "Warbands";
end

function WarbandsDialog:IsRunning()
	return ( self ~= nil );
end

function WarbandsDialog:Stop()
	self = nil;
end